@@ -1,4 +1,3 @@
-from .statsd_ import Statsd
 from .default import Default
 from .slack import SlackTelemeter
-from .statsd_ import Statsd
+from .statsd_ import StatsdTelemeter
