@@ -21,7 +21,10 @@ class StatsdTelemeter:
         self.client.incr(name, value, rate)
 
     def decr(self, name, value=1, rate=1):
-        self.incr(name, -value, rate)
+        self.client.incr(name, -value, rate)
 
     def timing(self, name, value, rate=1):
         self.client.timing(name, value, rate)
+
+    def send(self):
+        self.client.send()
